@@ -62,7 +62,7 @@ public:
 		};
 		char **argv;
 		unsigned short loop, argc; 
-		unsigned lnum, line, mask;
+		unsigned lnum, mask;
 		script::method_t method;
 	} line_t;
 
