@@ -212,7 +212,7 @@ const char *script::checks::chkStrict(script *img, script::header *scr, script::
 
 	if(!line->argc) {
 		script::strict::createGlobal(img, "error");
-		strict::strict::createGlobal(img, "index");
+		script::strict::createGlobal(img, "index");
 		return NULL;
 	}
 
