@@ -440,7 +440,8 @@ script *script::compile(const char *fn, script *cfg)
 	script::event *current;
 	script::event *prior;
 	char *tokens;
-	const char *token = NULL, *arg;
+	const char *token = NULL;
+	char *arg;
 	unsigned lnum = 0;
 	line_t *line, *last;
 	bool section = false;
@@ -730,7 +731,7 @@ parse:
 				formed = preparse(&tokens);
 				if(!formed)
 					break;
-				arg = String::token(NULL, &tokens, " \t", "{}\'\'\"\"");
+				arg = (char *)String::token(NULL, &tokens, " \t", "{}\'\'\"\"");
 			}
 			if(!arg)
 				break;
@@ -1242,3 +1243,32 @@ const char *script::get(const char *list, unsigned index)
 	return NULL;
 }
 
+char *script::get(char *list, unsigned index)
+{
+	char quote = 0;
+	unsigned paren = 0;
+
+	if(!list || !*list)
+		return NULL;
+
+	if(!index)
+		return list;
+
+	while(*list && index) {	
+		if(*list == ',' && !quote && !paren) {
+			--index;
+			if(!index) 
+				return ++list;
+		} else if(*list == quote)
+			quote = 0;
+		else if(*list == '(' && !quote)
+			++paren;
+		else if(*list == ')' && !quote)
+			--paren;
+		else if(*list == '\"' && !paren)
+			quote = *list;
+		++list;
+	}
+	return NULL;
+}
+
